import{d as H,T as E,y,C as D,z as R,x as T,A as B,g as V,bI as j,X as z,b_ as dt,B as $,Y as Ge,c0 as pt,W as gt,Z as ie,D as se,aL as We,V as O,aG as Z,a as ft,o as ht,c1 as mt,af as bt,a4 as ee,J as le,K as ue,at as yt,r as Ee,k as oe,aK as ce,aV as vt,b4 as Ze,c2 as wt,c3 as kt,c4 as _t,H as St,al as Xe,c5 as Fe,c6 as xt,c7 as Te,c8 as $t,an as At,bu as Et,au as G,bK as Ft,aJ as Tt,c9 as Ie,bo as It,O as Dt,aC as Pt,ca as Ct,cb as Rt,U as X,ah as De,aj as Pe,a6 as Ce,ai as zt,a0 as Vt}from"#entry";import{d as Nt,V as ke,f as Ot,c as Re,g as Lt,D as Mt,u as Bt}from"./vRc2BJuY.js";import{_ as U}from"./DlAUqK2U.js";import{V as ze}from"./Debz9GBs.js";import{V as qt}from"./DicsgTSm.js";import{T as Ke,V as Ht}from"./D4UZsoDo.js";import{S as Ut}from"./BOdr3NOm.js";import{R as jt,g as de}from"./EcQIca6j.js";const Gt=de`query scans($scanIds: [Int]) {
    scans(scanIds: $scanIds) {
        scans {
            id
            title
            progress
            riskRating
            agentGroup {
              id
              yamlSource
            }
            assets {
                __typename
                ... on OxoAndroidFileAssetType {
                  id
                  packageName
                  path
                }
                ... on OxoIOSFileAssetType {
                  id
                  bundleId
                  path
                }
                ... on OxoAndroidStoreAssetType {
                  id
                  packageName
                  applicationName
                }
                ... on OxoIOSStoreAssetType {
                  id
                  bundleId
                  applicationName
                }
                ... on OxoUrlsAssetType {
                  id
                  links {
                    url
                    method
                  }
                }
                ... on OxoNetworkAssetType {
                  id
                  networks {
                    host
                    mask
                  }
                }
                ... on OxoDomainNameAssetsType {
                  id
                  domainNames {
                    name
                  }
                }
            }
            createdTime
            kbVulnerabilities {
                highestRiskRating
                highestCvssV3Vector
                highestCvssV3BaseScore
                kb {
                    title
                    shortDescription
                    description
                    recommendation
                    references {
                        title
                        url
                    }
                }
                vulnerabilities {
                    vulnerabilities {
                        id
                        technicalDetail
                        riskRating
                        cvssV3Vector
                        detail {
                            title
                            shortDescription
                            description
                            recommendation
                            references {
                                title
                                url
                            }
                        }
                    }
                }
            }
        }
    }
}
`,Wt=de`
query Vulnerabilities(
    $scanId: Int!,
    $kbDetailTitle: String,
    $vulnDetailTitles: [String!]!,
    $numberElements: Int,
    $page: Int
) {
    scan(scanId: $scanId) {
        id
        kbVulnerabilities(detailTitle: $kbDetailTitle) {
            highestRiskRating
            vulnerabilities(detailTitles: $vulnDetailTitles, numberElements: $numberElements, page: $page) {
                pageInfo {
                  count
                  numPages
                  hasNext
                  hasPrevious
                }
                vulnerabilities {
                    id
                    technicalDetail
                    riskRating
                    dna
                    detail {
                        title
                        shortDescription
                        description
                        recommendation
                        references {
                          title
                          url
                        }
                    }
                }
            }
        }
    }
}
`,Zt=de`
query Vulnerabilities (
    $scanId: Int!,
    $vulnIds: [Int!]!,
) {
    scan(scanId: $scanId) {
        id
        vulnerabilities(vulnIds: $vulnIds) {
            vulnerabilities {
                id
                technicalDetail
                riskRating
                cvssV3Vector
                dna
                cvssV3BaseScore
                detail {
                    title
                    shortDescription
                    description
                    recommendation
                    references{
                        title
                        url
                    }
                }
            }
        }
    }
}
`,Xt=de`
query Vulnerabilities (
    $scanId: Int!,
    $page: Int!,
    $numberElements: Int!,
    $detailTitles: [String!]!
) {
    scan(scanId: $scanId) {
        id
        vulnerabilities(page: $page, numberElements: $numberElements, detailTitles: $detailTitles) {
            pageInfo {
              hasNext
              hasPrevious
              count
              numPages
            }
            vulnerabilities {
                id
                technicalDetail
                riskRating
                cvssV3Vector
                cvssV3BaseScore
            }
        }
    }
}
`;class he{requestHandler;hasNext;constructor(n){this.requestHandler=new jt(n),this.hasNext=!0}async getKBVulnerabilities(n,t){return((await this.requestHandler.post(n,{query:Gt,variables:{scanIds:[t]}}))?.data?.data?.scans?.scans||[])[0]||{}}async getVulnerabilitiesWithInfo({scanner:n,scanId:t,vulnDetailTitles:a,kbDetailTitle:l,page:c,numberElements:o}){const r=await this.requestHandler.post(n,{query:Wt,variables:{scanId:t,vulnDetailTitles:(a||[]).filter(Boolean),page:c,numberElements:o,kbDetailTitle:l}});return this.hasNext=r?.data?.data?.scan?.kbVulnerabilities[0]?.vulnerabilities?.pageInfo?.hasNext||!1,r?.data?.data?.scan?.kbVulnerabilities||[]}async getVulnerabilityByIdWithInfo({scanner:n,scanId:t,vulnIds:a}){return(await this.requestHandler.post(n,{query:Zt,variables:{scanId:t,vulnIds:a}}))?.data?.data?.scan?.vulnerabilities||{vulnerabilities:[]}}async getVulnerabilitiesWithoutInfo({scanner:n,scanId:t,detailTitles:a,page:l,numberElements:c}){const o=await this.requestHandler.post(n,{query:Xt,variables:{scanId:t,detailTitles:a,page:l,numberElements:c}});return this.hasNext=o?.data?.data?.scan?.vulnerabilities?.pageInfo?.hasNext||!1,o?.data?.data?.scan?.vulnerabilities?.vulnerabilities||[]}}var Ye=function(e){return function(n,t,a){return e(n,t,a)*a}},we=function(e,n){if(e)throw Error("Invalid sort config: "+n)},Je=function(e){var n=e||{},t=n.asc,a=n.desc,l=t?1:-1,c=t||a;we(!c,"Expected `asc` or `desc` property"),we(t&&a,"Ambiguous object with `asc` and `desc` config properties");var o=e.comparer&&Ye(e.comparer);return{order:l,sortBy:c,comparer:o}},Kt=function(e){return function n(t,a,l,c,o,r,d){var u,h;if(typeof t=="string")u=r[t],h=d[t];else if(typeof t=="function")u=t(r),h=t(d);else{var w=Je(t);return n(w.sortBy,a,l,w.order,w.comparer||e,r,d)}var S=o(u,h,c);return(S===0||u==null&&h==null)&&a.length>l?n(a[l],a,l+1,c,o,r,d):S}};function Qe(e,n,t){if(e===void 0||e===!0)return function(c,o){return n(c,o,t)};if(typeof e=="string")return we(e.includes("."),"String syntax not allowed for nested properties."),function(c,o){return n(c[e],o[e],t)};if(typeof e=="function")return function(c,o){return n(e(c),e(o),t)};if(Array.isArray(e)){var a=Kt(n);return function(c,o){return a(e[0],e,1,t,n,c,o)}}var l=Je(e);return Qe(l.sortBy,l.comparer||n,l.order)}var me=function(e,n,t,a){var l;return Array.isArray(n)?(Array.isArray(t)&&t.length<2&&(l=t,t=l[0]),n.sort(Qe(t,a,e))):n};function et(e){var n=Ye(e.comparer);return function(t){var a=Array.isArray(t)&&!e.inPlaceSorting?t.slice():t;return{asc:function(l){return me(1,a,l,n)},desc:function(l){return me(-1,a,l,n)},by:function(l){return me(1,a,l,n)}}}}var tt=function(e,n,t){return e==null?t:n==null?-t:typeof e!=typeof n?typeof e<typeof n?-1:1:e<n?-1:e>n?1:0},Yt=et({comparer:tt});et({comparer:tt,inPlaceSorting:!0});const Jt=new Error("request for lock canceled");var Qt=function(e,n,t,a){function l(c){return c instanceof t?c:new t(function(o){o(c)})}return new(t||(t=Promise))(function(c,o){function r(h){try{u(a.next(h))}catch(w){o(w)}}function d(h){try{u(a.throw(h))}catch(w){o(w)}}function u(h){h.done?c(h.value):l(h.value).then(r,d)}u((a=a.apply(e,n||[])).next())})};class en{constructor(n,t=Jt){this._value=n,this._cancelError=t,this._queue=[],this._weightedWaiters=[]}acquire(n=1,t=0){if(n<=0)throw new Error(`invalid weight ${n}: must be positive`);return new Promise((a,l)=>{const c={resolve:a,reject:l,weight:n,priority:t},o=nt(this._queue,r=>t<=r.priority);o===-1&&n<=this._value?this._dispatchItem(c):this._queue.splice(o+1,0,c)})}runExclusive(n){return Qt(this,arguments,void 0,function*(t,a=1,l=0){const[c,o]=yield this.acquire(a,l);try{return yield t(c)}finally{o()}})}waitForUnlock(n=1,t=0){if(n<=0)throw new Error(`invalid weight ${n}: must be positive`);return this._couldLockImmediately(n,t)?Promise.resolve():new Promise(a=>{this._weightedWaiters[n-1]||(this._weightedWaiters[n-1]=[]),tn(this._weightedWaiters[n-1],{resolve:a,priority:t})})}isLocked(){return this._value<=0}getValue(){return this._value}setValue(n){this._value=n,this._dispatchQueue()}release(n=1){if(n<=0)throw new Error(`invalid weight ${n}: must be positive`);this._value+=n,this._dispatchQueue()}cancel(){this._queue.forEach(n=>n.reject(this._cancelError)),this._queue=[]}_dispatchQueue(){for(this._drainUnlockWaiters();this._queue.length>0&&this._queue[0].weight<=this._value;)this._dispatchItem(this._queue.shift()),this._drainUnlockWaiters()}_dispatchItem(n){const t=this._value;this._value-=n.weight,n.resolve([t,this._newReleaser(n.weight)])}_newReleaser(n){let t=!1;return()=>{t||(t=!0,this.release(n))}}_drainUnlockWaiters(){if(this._queue.length===0)for(let n=this._value;n>0;n--){const t=this._weightedWaiters[n-1];t&&(t.forEach(a=>a.resolve()),this._weightedWaiters[n-1]=[])}else{const n=this._queue[0].priority;for(let t=this._value;t>0;t--){const a=this._weightedWaiters[t-1];if(!a)continue;const l=a.findIndex(c=>c.priority<=n);(l===-1?a:a.splice(0,l)).forEach((c=>c.resolve()))}}}_couldLockImmediately(n,t){return(this._queue.length===0||this._queue[0].priority<t)&&n<=this._value}}function tn(e,n){const t=nt(e,a=>n.priority<=a.priority);e.splice(t+1,0,n)}function nt(e,n){for(let t=e.length-1;t>=0;t--)if(n(e[t]))return t;return-1}var nn=function(e,n,t,a){function l(c){return c instanceof t?c:new t(function(o){o(c)})}return new(t||(t=Promise))(function(c,o){function r(h){try{u(a.next(h))}catch(w){o(w)}}function d(h){try{u(a.throw(h))}catch(w){o(w)}}function u(h){h.done?c(h.value):l(h.value).then(r,d)}u((a=a.apply(e,n||[])).next())})};class an{constructor(n){this._semaphore=new en(1,n)}acquire(){return nn(this,arguments,void 0,function*(n=0){const[,t]=yield this._semaphore.acquire(1,n);return t})}runExclusive(n,t=0){return this._semaphore.runExclusive(()=>n(),1,t)}isLocked(){return this._semaphore.isLocked()}waitForUnlock(n=0){return this._semaphore.waitForUnlock(1,n)}release(){this._semaphore.isLocked()&&this._semaphore.release()}cancel(){return this._semaphore.cancel()}}const rn=H({name:"VulnerabilityTitle",components:{DfRisk:Nt},props:{title:{type:String,required:!0},riskRating:{type:String,default:null},loading:{type:Boolean,default:!1}}}),sn={class:"text-h5 mb-2",style:{"font-size":"2rem","font-weight":"400"}},on={key:1},ln={class:"d-flex align-center"};function un(e,n,t,a,l,c){const o=V("DfRisk");return y(),E(ke,{class:"d-flex flex-column pa-3 vuln-details-page",variant:"outlined"},{default:D(()=>[R("p",sn,[e.loading===!0?(y(),E(ze,{key:0,"max-width":"500",type:"text@1"})):(y(),T("span",on,B(e.title),1))]),R("div",ln,[e.loading===!0?(y(),E(ze,{key:0,type:"button",style:{"flex-grow":"1"}})):(y(),E(o,{key:1,risk:e.riskRating,class:"mr-3"},null,8,["risk"]))])]),_:1})}const cn=U(rn,[["render",un]]),dn=H({name:"MaterialCard",props:{avatar:{type:String,default:""},tile:{type:Boolean,default:!1},color:{type:String,default:"success"},hoverReveal:{type:Boolean,default:!1},icon:{type:String,default:void 0},image:{type:Boolean,default:!1},inline:{type:Boolean,default:!1},text:{type:String,default:""},title:{type:String,default:""}},computed:{classes(){return{"v-card--material--has-heading":this.hasHeading,"v-card--material--hover-reveal":this.hoverReveal}},hasHeading(){return!!(this.$slots.heading||this.title||this.icon)},hasAltHeading(){return!!(this.$slots.heading||this.title&&this.icon)}}}),pn={class:"d-flex grow flex-wrap"},gn={key:2,class:"display-1 font-weight-bold"},fn={key:4,class:"headline font-weight-thin"},hn={key:2,class:"ml-6"},mn={key:4,class:"ml-4 d-flex"},bn={class:"font-weight-bold",style:{"font-size":"1.3rem"}},yn={class:"ml-3 mt-2",style:{"font-size":"0.9rem"}};function vn(e,n,t,a,l,c){return y(),E(ke,Z({variant:"outlined"},e.$attrs,{class:[e.classes,"v-card--material pa-3"],style:{overflow:"visible"}}),{default:D(()=>[R("div",pn,[e.avatar?(y(),E(dt,{key:0,size:"128",class:"mx-auto v-card--material__avatar elevation-12",tile:e.tile},{default:D(()=>[$(Ge,{src:e.avatar},null,8,["src"])]),_:1},8,["tile"])):(y(),E(pt,{key:1,class:gt([{"pa-7":!e.$slots.image},"text-start v-card--material__heading mb-n6"]),color:e.color,"max-height":e.icon?75:void 0,width:e.inline||e.icon?"auto":"100%",dark:"",style:{"border-radius":"4px"}},{default:D(()=>[e.$slots.heading?j(e.$slots,"heading",{key:0}):e.$slots.image?j(e.$slots,"image",{key:1}):e.title&&!e.icon?(y(),T("p",gn,B(e.title),1)):e.icon?(y(),E(ie,{key:3,size:"24"},{default:D(()=>[se(B(e.icon),1)]),_:1})):z("",!0),e.text?(y(),T("p",fn,B(e.text),1)):z("",!0)]),_:3},8,["class","color","max-height","width"])),e.$slots["after-heading"]?(y(),T("div",hn,[j(e.$slots,"after-heading")])):z("",!0),e.hoverReveal?(y(),E(qt,{key:3,cols:"12",class:"text-center py-0 mt-n12"},{default:D(()=>[j(e.$slots,"reveal-actions")]),_:3})):e.icon&&e.title?(y(),T("div",mn,[R("div",bn,B(e.title),1),R("div",yn,[j(e.$slots,"title-extra-info")])])):z("",!0)]),j(e.$slots,"default"),e.$slots.actions?(y(),T(O,{key:0},[$(We,{class:"mt-2"}),$(Ot,{class:"pb-0"},{default:D(()=>[j(e.$slots,"actions")]),_:3})],64)):z("",!0)]),_:3},16,["class"])}const wn=U(dn,[["render",vn]]);var be={exports:{}},Ve;function kn(){return Ve||(Ve=1,(function(e){var n=typeof window<"u"?window:typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope?self:{};/**
 * Prism: Lightweight, robust, elegant syntax highlighting
 *
 * @license MIT <https://opensource.org/licenses/MIT>
 * @author Lea Verou <https://lea.verou.me>
 * @namespace
 * @public
 */var t=(function(a){var l=/(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i,c=0,o={},r={manual:a.Prism&&a.Prism.manual,disableWorkerMessageHandler:a.Prism&&a.Prism.disableWorkerMessageHandler,util:{encode:function i(s){return s instanceof d?new d(s.type,i(s.content),s.alias):Array.isArray(s)?s.map(i):s.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/\u00a0/g," ")},type:function(i){return Object.prototype.toString.call(i).slice(8,-1)},objId:function(i){return i.__id||Object.defineProperty(i,"__id",{value:++c}),i.__id},clone:function i(s,g){g=g||{};var p,f;switch(r.util.type(s)){case"Object":if(f=r.util.objId(s),g[f])return g[f];p={},g[f]=p;for(var b in s)s.hasOwnProperty(b)&&(p[b]=i(s[b],g));return p;case"Array":return f=r.util.objId(s),g[f]?g[f]:(p=[],g[f]=p,s.forEach(function(k,m){p[m]=i(k,g)}),p);default:return s}},getLanguage:function(i){for(;i;){var s=l.exec(i.className);if(s)return s[1].toLowerCase();i=i.parentElement}return"none"},setLanguage:function(i,s){i.className=i.className.replace(RegExp(l,"gi"),""),i.classList.add("language-"+s)},currentScript:function(){if(typeof document>"u")return null;if(document.currentScript&&document.currentScript.tagName==="SCRIPT")return document.currentScript;try{throw new Error}catch(p){var i=(/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(p.stack)||[])[1];if(i){var s=document.getElementsByTagName("script");for(var g in s)if(s[g].src==i)return s[g]}return null}},isActive:function(i,s,g){for(var p="no-"+s;i;){var f=i.classList;if(f.contains(s))return!0;if(f.contains(p))return!1;i=i.parentElement}return!!g}},languages:{plain:o,plaintext:o,text:o,txt:o,extend:function(i,s){var g=r.util.clone(r.languages[i]);for(var p in s)g[p]=s[p];return g},insertBefore:function(i,s,g,p){p=p||r.languages;var f=p[i],b={};for(var k in f)if(f.hasOwnProperty(k)){if(k==s)for(var m in g)g.hasOwnProperty(m)&&(b[m]=g[m]);g.hasOwnProperty(k)||(b[k]=f[k])}var I=p[i];return p[i]=b,r.languages.DFS(r.languages,function(P,L){L===I&&P!=i&&(this[P]=b)}),b},DFS:function i(s,g,p,f){f=f||{};var b=r.util.objId;for(var k in s)if(s.hasOwnProperty(k)){g.call(s,k,s[k],p||k);var m=s[k],I=r.util.type(m);I==="Object"&&!f[b(m)]?(f[b(m)]=!0,i(m,g,null,f)):I==="Array"&&!f[b(m)]&&(f[b(m)]=!0,i(m,g,k,f))}}},plugins:{},highlightAll:function(i,s){r.highlightAllUnder(document,i,s)},highlightAllUnder:function(i,s,g){var p={callback:g,container:i,selector:'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'};r.hooks.run("before-highlightall",p),p.elements=Array.prototype.slice.apply(p.container.querySelectorAll(p.selector)),r.hooks.run("before-all-elements-highlight",p);for(var f=0,b;b=p.elements[f++];)r.highlightElement(b,s===!0,p.callback)},highlightElement:function(i,s,g){var p=r.util.getLanguage(i),f=r.languages[p];r.util.setLanguage(i,p);var b=i.parentElement;b&&b.nodeName.toLowerCase()==="pre"&&r.util.setLanguage(b,p);var k=i.textContent,m={element:i,language:p,grammar:f,code:k};function I(L){m.highlightedCode=L,r.hooks.run("before-insert",m),m.element.innerHTML=m.highlightedCode,r.hooks.run("after-highlight",m),r.hooks.run("complete",m),g&&g.call(m.element)}if(r.hooks.run("before-sanity-check",m),b=m.element.parentElement,b&&b.nodeName.toLowerCase()==="pre"&&!b.hasAttribute("tabindex")&&b.setAttribute("tabindex","0"),!m.code){r.hooks.run("complete",m),g&&g.call(m.element);return}if(r.hooks.run("before-highlight",m),!m.grammar){I(r.util.encode(m.code));return}if(s&&a.Worker){var P=new Worker(r.filename);P.onmessage=function(L){I(L.data)},P.postMessage(JSON.stringify({language:m.language,code:m.code,immediateClose:!0}))}else I(r.highlight(m.code,m.grammar,m.language))},highlight:function(i,s,g){var p={code:i,grammar:s,language:g};if(r.hooks.run("before-tokenize",p),!p.grammar)throw new Error('The language "'+p.language+'" has no grammar.');return p.tokens=r.tokenize(p.code,p.grammar),r.hooks.run("after-tokenize",p),d.stringify(r.util.encode(p.tokens),p.language)},tokenize:function(i,s){var g=s.rest;if(g){for(var p in g)s[p]=g[p];delete s.rest}var f=new w;return S(f,f.head,i),h(i,f,s,f.head,0),A(f)},hooks:{all:{},add:function(i,s){var g=r.hooks.all;g[i]=g[i]||[],g[i].push(s)},run:function(i,s){var g=r.hooks.all[i];if(!(!g||!g.length))for(var p=0,f;f=g[p++];)f(s)}},Token:d};a.Prism=r;function d(i,s,g,p){this.type=i,this.content=s,this.alias=g,this.length=(p||"").length|0}d.stringify=function i(s,g){if(typeof s=="string")return s;if(Array.isArray(s)){var p="";return s.forEach(function(I){p+=i(I,g)}),p}var f={type:s.type,content:i(s.content,g),tag:"span",classes:["token",s.type],attributes:{},language:g},b=s.alias;b&&(Array.isArray(b)?Array.prototype.push.apply(f.classes,b):f.classes.push(b)),r.hooks.run("wrap",f);var k="";for(var m in f.attributes)k+=" "+m+'="'+(f.attributes[m]||"").replace(/"/g,"&quot;")+'"';return"<"+f.tag+' class="'+f.classes.join(" ")+'"'+k+">"+f.content+"</"+f.tag+">"};function u(i,s,g,p){i.lastIndex=s;var f=i.exec(g);if(f&&p&&f[1]){var b=f[1].length;f.index+=b,f[0]=f[0].slice(b)}return f}function h(i,s,g,p,f,b){for(var k in g)if(!(!g.hasOwnProperty(k)||!g[k])){var m=g[k];m=Array.isArray(m)?m:[m];for(var I=0;I<m.length;++I){if(b&&b.cause==k+","+I)return;var P=m[I],L=P.inside,Y=!!P.lookbehind,xe=!!P.greedy,ot=P.alias;if(xe&&!P.pattern.global){var lt=P.pattern.toString().match(/[imsuy]*$/)[0];P.pattern=RegExp(P.pattern.source,lt+"g")}for(var $e=P.pattern||P,C=p.next,M=f;C!==s.tail&&!(b&&M>=b.reach);M+=C.value.length,C=C.next){var K=C.value;if(s.length>i.length)return;if(!(K instanceof d)){var te=1,N;if(xe){if(N=u($e,M,i,Y),!N||N.index>=i.length)break;var ne=N.index,ut=N.index+N[0].length,q=M;for(q+=C.value.length;ne>=q;)C=C.next,q+=C.value.length;if(q-=C.value.length,M=q,C.value instanceof d)continue;for(var J=C;J!==s.tail&&(q<ut||typeof J.value=="string");J=J.next)te++,q+=J.value.length;te--,K=i.slice(M,q),N.index-=M}else if(N=u($e,0,K,Y),!N)continue;var ne=N.index,ae=N[0],pe=K.slice(0,ne),Ae=K.slice(ne+ae.length),ge=M+K.length;b&&ge>b.reach&&(b.reach=ge);var re=C.prev;pe&&(re=S(s,re,pe),M+=pe.length),F(s,re,te);var ct=new d(k,L?r.tokenize(ae,L):ae,ot,ae);if(C=S(s,re,ct),Ae&&S(s,C,Ae),te>1){var fe={cause:k+","+I,reach:ge};h(i,s,g,C.prev,M,fe),b&&fe.reach>b.reach&&(b.reach=fe.reach)}}}}}}function w(){var i={value:null,prev:null,next:null},s={value:null,prev:i,next:null};i.next=s,this.head=i,this.tail=s,this.length=0}function S(i,s,g){var p=s.next,f={value:g,prev:s,next:p};return s.next=f,p.prev=f,i.length++,f}function F(i,s,g){for(var p=s.next,f=0;f<g&&p!==i.tail;f++)p=p.next;s.next=p,p.prev=s,i.length-=f}function A(i){for(var s=[],g=i.head.next;g!==i.tail;)s.push(g.value),g=g.next;return s}if(!a.document)return a.addEventListener&&(r.disableWorkerMessageHandler||a.addEventListener("message",function(i){var s=JSON.parse(i.data),g=s.language,p=s.code,f=s.immediateClose;a.postMessage(r.highlight(p,r.languages[g],g)),f&&a.close()},!1)),r;var x=r.util.currentScript();x&&(r.filename=x.src,x.hasAttribute("data-manual")&&(r.manual=!0));function v(){r.manual||r.highlightAll()}if(!r.manual){var _=document.readyState;_==="loading"||_==="interactive"&&x&&x.defer?document.addEventListener("DOMContentLoaded",v):window.requestAnimationFrame?window.requestAnimationFrame(v):window.setTimeout(v,16)}return r})(n);e.exports&&(e.exports=t),typeof Re<"u"&&(Re.Prism=t),t.languages.markup={comment:{pattern:/<!--(?:(?!<!--)[\s\S])*?-->/,greedy:!0},prolog:{pattern:/<\?[\s\S]+?\?>/,greedy:!0},doctype:{pattern:/<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,greedy:!0,inside:{"internal-subset":{pattern:/(^[^\[]*\[)[\s\S]+(?=\]>$)/,lookbehind:!0,greedy:!0,inside:null},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},punctuation:/^<!|>$|[[\]]/,"doctype-tag":/^DOCTYPE/i,name:/[^\s<>'"]+/}},cdata:{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,greedy:!0},tag:{pattern:/<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,greedy:!0,inside:{tag:{pattern:/^<\/?[^\s>\/]+/,inside:{punctuation:/^<\/?/,namespace:/^[^\s>\/:]+:/}},"special-attr":[],"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,inside:{punctuation:[{pattern:/^=/,alias:"attr-equals"},{pattern:/^(\s*)["']|["']$/,lookbehind:!0}]}},punctuation:/\/?>/,"attr-name":{pattern:/[^\s>\/]+/,inside:{namespace:/^[^\s>\/:]+:/}}}},entity:[{pattern:/&[\da-z]{1,8};/i,alias:"named-entity"},/&#x?[\da-f]{1,8};/i]},t.languages.markup.tag.inside["attr-value"].inside.entity=t.languages.markup.entity,t.languages.markup.doctype.inside["internal-subset"].inside=t.languages.markup,t.hooks.add("wrap",function(a){a.type==="entity"&&(a.attributes.title=a.content.replace(/&amp;/,"&"))}),Object.defineProperty(t.languages.markup.tag,"addInlined",{value:function(l,c){var o={};o["language-"+c]={pattern:/(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,lookbehind:!0,inside:t.languages[c]},o.cdata=/^<!\[CDATA\[|\]\]>$/i;var r={"included-cdata":{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,inside:o}};r["language-"+c]={pattern:/[\s\S]+/,inside:t.languages[c]};var d={};d[l]={pattern:RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g,function(){return l}),"i"),lookbehind:!0,greedy:!0,inside:r},t.languages.insertBefore("markup","cdata",d)}}),Object.defineProperty(t.languages.markup.tag,"addAttribute",{value:function(a,l){t.languages.markup.tag.inside["special-attr"].push({pattern:RegExp(/(^|["'\s])/.source+"(?:"+a+")"+/\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,"i"),lookbehind:!0,inside:{"attr-name":/^[^\s=]+/,"attr-value":{pattern:/=[\s\S]+/,inside:{value:{pattern:/(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,lookbehind:!0,alias:[l,"language-"+l],inside:t.languages[l]},punctuation:[{pattern:/^=/,alias:"attr-equals"},/"|'/]}}}})}}),t.languages.html=t.languages.markup,t.languages.mathml=t.languages.markup,t.languages.svg=t.languages.markup,t.languages.xml=t.languages.extend("markup",{}),t.languages.ssml=t.languages.xml,t.languages.atom=t.languages.xml,t.languages.rss=t.languages.xml,(function(a){var l=/(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;a.languages.css={comment:/\/\*[\s\S]*?\*\//,atrule:{pattern:RegExp("@[\\w-](?:"+/[^;{\s"']|\s+(?!\s)/.source+"|"+l.source+")*?"+/(?:;|(?=\s*\{))/.source),inside:{rule:/^@[\w-]+/,"selector-function-argument":{pattern:/(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,lookbehind:!0,alias:"selector"},keyword:{pattern:/(^|[^\w-])(?:and|not|only|or)(?![\w-])/,lookbehind:!0}}},url:{pattern:RegExp("\\burl\\((?:"+l.source+"|"+/(?:[^\\\r\n()"']|\\[\s\S])*/.source+")\\)","i"),greedy:!0,inside:{function:/^url/i,punctuation:/^\(|\)$/,string:{pattern:RegExp("^"+l.source+"$"),alias:"url"}}},selector:{pattern:RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|`+l.source+")*(?=\\s*\\{)"),lookbehind:!0},string:{pattern:l,greedy:!0},property:{pattern:/(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,lookbehind:!0},important:/!important\b/i,function:{pattern:/(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,lookbehind:!0},punctuation:/[(){};:,]/},a.languages.css.atrule.inside.rest=a.languages.css;var c=a.languages.markup;c&&(c.tag.addInlined("style","css"),c.tag.addAttribute("style","css"))})(t),t.languages.clike={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b\w+(?=\()/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,punctuation:/[{}[\];(),.:]/},t.languages.javascript=t.languages.extend("clike",{"class-name":[t.languages.clike["class-name"],{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,lookbehind:!0}],keyword:[{pattern:/((?:^|\})\s*)catch\b/,lookbehind:!0},{pattern:/(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,lookbehind:!0}],function:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,number:{pattern:RegExp(/(^|[^\w$])/.source+"(?:"+(/NaN|Infinity/.source+"|"+/0[bB][01]+(?:_[01]+)*n?/.source+"|"+/0[oO][0-7]+(?:_[0-7]+)*n?/.source+"|"+/0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source+"|"+/\d+(?:_\d+)*n/.source+"|"+/(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source)+")"+/(?![\w$])/.source),lookbehind:!0},operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/}),t.languages.javascript["class-name"][0].pattern=/(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/,t.languages.insertBefore("javascript","keyword",{regex:{pattern:RegExp(/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)/.source+/\//.source+"(?:"+/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}/.source+"|"+/(?:\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.|\[(?:[^[\]\\\r\n]|\\.)*\])*\])*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}v[dgimyus]{0,7}/.source+")"+/(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/.source),lookbehind:!0,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^\/|\/$/,"regex-flags":/^[a-z]+$/}},"function-variable":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"},parameter:[{pattern:/(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,lookbehind:!0,inside:t.languages.javascript},{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,lookbehind:!0,inside:t.languages.javascript},{pattern:/(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,lookbehind:!0,inside:t.languages.javascript},{pattern:/((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,lookbehind:!0,inside:t.languages.javascript}],constant:/\b[A-Z](?:[A-Z_]|\dx?)*\b/}),t.languages.insertBefore("javascript","string",{hashbang:{pattern:/^#!.*/,greedy:!0,alias:"comment"},"template-string":{pattern:/`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:t.languages.javascript}},string:/[\s\S]+/}},"string-property":{pattern:/((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,lookbehind:!0,greedy:!0,alias:"property"}}),t.languages.insertBefore("javascript","operator",{"literal-property":{pattern:/((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,lookbehind:!0,alias:"property"}}),t.languages.markup&&(t.languages.markup.tag.addInlined("script","javascript"),t.languages.markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,"javascript")),t.languages.js=t.languages.javascript,(function(){if(typeof t>"u"||typeof document>"u")return;Element.prototype.matches||(Element.prototype.matches=Element.prototype.msMatchesSelector||Element.prototype.webkitMatchesSelector);var a="Loading…",l=function(x,v){return"✖ Error "+x+" while fetching file: "+v},c="✖ Error: File does not exist or is empty",o={js:"javascript",py:"python",rb:"ruby",ps1:"powershell",psm1:"powershell",sh:"bash",bat:"batch",h:"c",tex:"latex"},r="data-src-status",d="loading",u="loaded",h="failed",w="pre[data-src]:not(["+r+'="'+u+'"]):not(['+r+'="'+d+'"])';function S(x,v,_){var i=new XMLHttpRequest;i.open("GET",x,!0),i.onreadystatechange=function(){i.readyState==4&&(i.status<400&&i.responseText?v(i.responseText):i.status>=400?_(l(i.status,i.statusText)):_(c))},i.send(null)}function F(x){var v=/^\s*(\d+)\s*(?:(,)\s*(?:(\d+)\s*)?)?$/.exec(x||"");if(v){var _=Number(v[1]),i=v[2],s=v[3];return i?s?[_,Number(s)]:[_,void 0]:[_,_]}}t.hooks.add("before-highlightall",function(x){x.selector+=", "+w}),t.hooks.add("before-sanity-check",function(x){var v=x.element;if(v.matches(w)){x.code="",v.setAttribute(r,d);var _=v.appendChild(document.createElement("CODE"));_.textContent=a;var i=v.getAttribute("data-src"),s=x.language;if(s==="none"){var g=(/\.(\w+)$/.exec(i)||[,"none"])[1];s=o[g]||g}t.util.setLanguage(_,s),t.util.setLanguage(v,s);var p=t.plugins.autoloader;p&&p.loadLanguages(s),S(i,function(f){v.setAttribute(r,u);var b=F(v.getAttribute("data-range"));if(b){var k=f.split(/\r\n?|\n/g),m=b[0],I=b[1]==null?k.length:b[1];m<0&&(m+=k.length),m=Math.max(0,Math.min(m-1,k.length)),I<0&&(I+=k.length),I=Math.max(0,Math.min(I,k.length)),f=k.slice(m,I).join(`
`),v.hasAttribute("data-start")||v.setAttribute("data-start",String(m+1))}_.textContent=f,t.highlightElement(_)},function(f){v.setAttribute(r,h),_.textContent=f})}}),t.plugins.fileHighlight={highlight:function(v){for(var _=(v||document).querySelectorAll(w),i=0,s;s=_[i++];)t.highlightElement(s)}};var A=!1;t.fileHighlight=function(){A||(console.warn("Prism.fileHighlight is deprecated. Use `Prism.plugins.fileHighlight.highlight` instead."),A=!0),t.plugins.fileHighlight.highlight.apply(this,arguments)}})()})(be)),be.exports}var _n=kn();const Ne=Lt(_n);(function(e){var n="\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b",t={pattern:/(^(["']?)\w+\2)[ \t]+\S.*/,lookbehind:!0,alias:"punctuation",inside:null},a={bash:t,environment:{pattern:RegExp("\\$"+n),alias:"constant"},variable:[{pattern:/\$?\(\([\s\S]+?\)\)/,greedy:!0,inside:{variable:[{pattern:/(^\$\(\([\s\S]+)\)\)/,lookbehind:!0},/^\$\(\(/],number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,punctuation:/\(\(?|\)\)?|,|;/}},{pattern:/\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,greedy:!0,inside:{variable:/^\$\(|^`|\)$|`$/}},{pattern:/\$\{[^}]+\}/,greedy:!0,inside:{operator:/:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,punctuation:/[\[\]]/,environment:{pattern:RegExp("(\\{)"+n),lookbehind:!0,alias:"constant"}}},/\$(?:\w+|[#?*!@$])/],entity:/\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/};e.languages.bash={shebang:{pattern:/^#!\s*\/.*/,alias:"important"},comment:{pattern:/(^|[^"{\\$])#.*/,lookbehind:!0},"function-name":[{pattern:/(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,lookbehind:!0,alias:"function"},{pattern:/\b[\w-]+(?=\s*\(\s*\)\s*\{)/,alias:"function"}],"for-or-select":{pattern:/(\b(?:for|select)\s+)\w+(?=\s+in\s)/,alias:"variable",lookbehind:!0},"assign-left":{pattern:/(^|[\s;|&]|[<>]\()\w+(?:\.\w+)*(?=\+?=)/,inside:{environment:{pattern:RegExp("(^|[\\s;|&]|[<>]\\()"+n),lookbehind:!0,alias:"constant"}},alias:"variable",lookbehind:!0},parameter:{pattern:/(^|\s)-{1,2}(?:\w+:[+-]?)?\w+(?:\.\w+)*(?=[=\s]|$)/,alias:"variable",lookbehind:!0},string:[{pattern:/((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,lookbehind:!0,greedy:!0,inside:a},{pattern:/((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,lookbehind:!0,greedy:!0,inside:{bash:t}},{pattern:/(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,lookbehind:!0,greedy:!0,inside:a},{pattern:/(^|[^$\\])'[^']*'/,lookbehind:!0,greedy:!0},{pattern:/\$'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{entity:a.entity}}],environment:{pattern:RegExp("\\$?"+n),alias:"constant"},variable:a.variable,function:{pattern:/(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cargo|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|java|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|sysctl|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,lookbehind:!0},keyword:{pattern:/(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,lookbehind:!0},builtin:{pattern:/(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,lookbehind:!0,alias:"class-name"},boolean:{pattern:/(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,lookbehind:!0},"file-descriptor":{pattern:/\B&\d\b/,alias:"important"},operator:{pattern:/\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,inside:{"file-descriptor":{pattern:/^\d/,alias:"important"}}},punctuation:/\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,number:{pattern:/(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,lookbehind:!0}},t.inside=e.languages.bash;for(var l=["comment","function-name","for-or-select","assign-left","parameter","string","environment","function","keyword","builtin","boolean","file-descriptor","operator","punctuation","number"],c=a.variable[1].inside,o=0;o<l.length;o++)c[l[o]]=e.languages.bash[l[o]];e.languages.sh=e.languages.bash,e.languages.shell=e.languages.bash})(Prism);Prism.languages.javascript=Prism.languages.extend("clike",{"class-name":[Prism.languages.clike["class-name"],{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,lookbehind:!0}],keyword:[{pattern:/((?:^|\})\s*)catch\b/,lookbehind:!0},{pattern:/(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,lookbehind:!0}],function:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,number:{pattern:RegExp("(^|[^\\w$])(?:NaN|Infinity|0[bB][01]+(?:_[01]+)*n?|0[oO][0-7]+(?:_[0-7]+)*n?|0[xX][\\dA-Fa-f]+(?:_[\\dA-Fa-f]+)*n?|\\d+(?:_\\d+)*n|(?:\\d+(?:_\\d+)*(?:\\.(?:\\d+(?:_\\d+)*)?)?|\\.\\d+(?:_\\d+)*)(?:[Ee][+-]?\\d+(?:_\\d+)*)?)(?![\\w$])"),lookbehind:!0},operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/}),Prism.languages.javascript["class-name"][0].pattern=/(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/,Prism.languages.insertBefore("javascript","keyword",{regex:{pattern:RegExp(`((?:^|[^$\\w\\xA0-\\uFFFF."'\\])\\s]|\\b(?:return|yield))\\s*)/(?:(?:\\[(?:[^\\]\\\\\r
]|\\\\.)*\\]|\\\\.|[^/\\\\\\[\r
])+/[dgimyus]{0,7}|(?:\\[(?:[^[\\]\\\\\r
]|\\\\.|\\[(?:[^[\\]\\\\\r
]|\\\\.|\\[(?:[^[\\]\\\\\r
]|\\\\.)*\\])*\\])*\\]|\\\\.|[^/\\\\\\[\r
])+/[dgimyus]{0,7}v[dgimyus]{0,7})(?=(?:\\s|/\\*(?:[^*]|\\*(?!/))*\\*/)*(?:$|[\r
,.;:})\\]]|//))`),lookbehind:!0,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:Prism.languages.regex},"regex-delimiter":/^\/|\/$/,"regex-flags":/^[a-z]+$/}},"function-variable":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"},parameter:[{pattern:/(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,lookbehind:!0,inside:Prism.languages.javascript},{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,lookbehind:!0,inside:Prism.languages.javascript},{pattern:/(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,lookbehind:!0,inside:Prism.languages.javascript},{pattern:/((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,lookbehind:!0,inside:Prism.languages.javascript}],constant:/\b[A-Z](?:[A-Z_]|\dx?)*\b/}),Prism.languages.insertBefore("javascript","string",{hashbang:{pattern:/^#!.*/,greedy:!0,alias:"comment"},"template-string":{pattern:/`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:Prism.languages.javascript}},string:/[\s\S]+/}},"string-property":{pattern:/((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,lookbehind:!0,greedy:!0,alias:"property"}}),Prism.languages.insertBefore("javascript","operator",{"literal-property":{pattern:/((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,lookbehind:!0,alias:"property"}}),Prism.languages.markup&&(Prism.languages.markup.tag.addInlined("script","javascript"),Prism.languages.markup.tag.addAttribute("on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)","javascript")),Prism.languages.js=Prism.languages.javascript;Prism.languages.json={property:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\],]/,operator:/:/,boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"}},Prism.languages.webmanifest=Prism.languages.json;(function(e){e.languages.kotlin=e.languages.extend("clike",{keyword:{pattern:/(^|[^.])\b(?:abstract|actual|annotation|as|break|by|catch|class|companion|const|constructor|continue|crossinline|data|do|dynamic|else|enum|expect|external|final|finally|for|fun|get|if|import|in|infix|init|inline|inner|interface|internal|is|lateinit|noinline|null|object|open|operator|out|override|package|private|protected|public|reified|return|sealed|set|super|suspend|tailrec|this|throw|to|try|typealias|val|var|vararg|when|where|while)\b/,lookbehind:!0},function:[{pattern:/(?:`[^\r\n`]+`|\b\w+)(?=\s*\()/,greedy:!0},{pattern:/(\.)(?:`[^\r\n`]+`|\w+)(?=\s*\{)/,lookbehind:!0,greedy:!0}],number:/\b(?:0[xX][\da-fA-F]+(?:_[\da-fA-F]+)*|0[bB][01]+(?:_[01]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?[fFL]?)\b/,operator:/\+[+=]?|-[-=>]?|==?=?|!(?:!|==?)?|[\/*%<>]=?|[?:]:?|\.\.|&&|\|\||\b(?:and|inv|or|shl|shr|ushr|xor)\b/}),delete e.languages.kotlin["class-name"];var n={"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:e.languages.kotlin}};e.languages.insertBefore("kotlin","string",{"string-literal":[{pattern:/"""(?:[^$]|\$(?:(?!\{)|\{[^{}]*\}))*?"""/,alias:"multiline",inside:{interpolation:{pattern:/\$(?:[a-z_]\w*|\{[^{}]*\})/i,inside:n},string:/[\s\S]+/}},{pattern:/"(?:[^"\\\r\n$]|\\.|\$(?:(?!\{)|\{[^{}]*\}))*"/,alias:"singleline",inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:[a-z_]\w*|\{[^{}]*\})/i,lookbehind:!0,inside:n},string:/[\s\S]+/}}],char:{pattern:/'(?:[^'\\\r\n]|\\(?:.|u[a-fA-F0-9]{0,4}))'/,greedy:!0}}),delete e.languages.kotlin.string,e.languages.insertBefore("kotlin","keyword",{annotation:{pattern:/\B@(?:\w+:)?(?:[A-Z]\w*|\[[^\]]+\])/,alias:"builtin"}}),e.languages.insertBefore("kotlin","function",{label:{pattern:/\b\w+@|@\w+\b/,alias:"symbol"}}),e.languages.kt=e.languages.kotlin,e.languages.kts=e.languages.kotlin})(Prism);(function(e){function n(d){return d=d.replace(/<inner>/g,(function(){return`(?:\\\\.|[^\\\\
\r]|(?:
|\r
?)(?![\r
]))`})),RegExp("((?:^|[^\\\\])(?:\\\\{2})*)(?:"+d+")")}var t="(?:\\\\.|``(?:[^`\r\n]|`(?!`))+``|`[^`\r\n]+`|[^\\\\|\r\n`])+",a=`\\|?__(?:\\|__)+\\|?(?:(?:
|\r
?)|(?![^]))`.replace(/__/g,(function(){return t})),l=`\\|?[ 	]*:?-{3,}:?[ 	]*(?:\\|[ 	]*:?-{3,}:?[ 	]*)+\\|?(?:
|\r
?)`;e.languages.markdown=e.languages.extend("markup",{}),e.languages.insertBefore("markdown","prolog",{"front-matter-block":{pattern:/(^(?:\s*[\r\n])?)---(?!.)[\s\S]*?[\r\n]---(?!.)/,lookbehind:!0,greedy:!0,inside:{punctuation:/^---|---$/,"front-matter":{pattern:/\S+(?:\s+\S+)*/,alias:["yaml","language-yaml"],inside:e.languages.yaml}}},blockquote:{pattern:/^>(?:[\t ]*>)*/m,alias:"punctuation"},table:{pattern:RegExp("^"+a+l+"(?:"+a+")*","m"),inside:{"table-data-rows":{pattern:RegExp("^("+a+l+")(?:"+a+")*$"),lookbehind:!0,inside:{"table-data":{pattern:RegExp(t),inside:e.languages.markdown},punctuation:/\|/}},"table-line":{pattern:RegExp("^("+a+")"+l+"$"),lookbehind:!0,inside:{punctuation:/\||:?-{3,}:?/}},"table-header-row":{pattern:RegExp("^"+a+"$"),inside:{"table-header":{pattern:RegExp(t),alias:"important",inside:e.languages.markdown},punctuation:/\|/}}}},code:[{pattern:/((?:^|\n)[ \t]*\n|(?:^|\r\n?)[ \t]*\r\n?)(?: {4}|\t).+(?:(?:\n|\r\n?)(?: {4}|\t).+)*/,lookbehind:!0,alias:"keyword"},{pattern:/^```[\s\S]*?^```$/m,greedy:!0,inside:{"code-block":{pattern:/^(```.*(?:\n|\r\n?))[\s\S]+?(?=(?:\n|\r\n?)^```$)/m,lookbehind:!0},"code-language":{pattern:/^(```).+/,lookbehind:!0},punctuation:/```/}}],title:[{pattern:/\S.*(?:\n|\r\n?)(?:==+|--+)(?=[ \t]*$)/m,alias:"important",inside:{punctuation:/==+$|--+$/}},{pattern:/(^\s*)#.+/m,lookbehind:!0,alias:"important",inside:{punctuation:/^#+|#+$/}}],hr:{pattern:/(^\s*)([*-])(?:[\t ]*\2){2,}(?=\s*$)/m,lookbehind:!0,alias:"punctuation"},list:{pattern:/(^\s*)(?:[*+-]|\d+\.)(?=[\t ].)/m,lookbehind:!0,alias:"punctuation"},"url-reference":{pattern:/!?\[[^\]]+\]:[\t ]+(?:\S+|<(?:\\.|[^>\\])+>)(?:[\t ]+(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\)))?/,inside:{variable:{pattern:/^(!?\[)[^\]]+/,lookbehind:!0},string:/(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\))$/,punctuation:/^[\[\]!:]|[<>]/},alias:"url"},bold:{pattern:n("\\b__(?:(?!_)<inner>|_(?:(?!_)<inner>)+_)+__\\b|\\*\\*(?:(?!\\*)<inner>|\\*(?:(?!\\*)<inner>)+\\*)+\\*\\*"),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^..)[\s\S]+(?=..$)/,lookbehind:!0,inside:{}},punctuation:/\*\*|__/}},italic:{pattern:n("\\b_(?:(?!_)<inner>|__(?:(?!_)<inner>)+__)+_\\b|\\*(?:(?!\\*)<inner>|\\*\\*(?:(?!\\*)<inner>)+\\*\\*)+\\*"),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^.)[\s\S]+(?=.$)/,lookbehind:!0,inside:{}},punctuation:/[*_]/}},strike:{pattern:n("(~~?)(?:(?!~)<inner>)+\\2"),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^~~?)[\s\S]+(?=\1$)/,lookbehind:!0,inside:{}},punctuation:/~~?/}},"code-snippet":{pattern:/(^|[^\\`])(?:``[^`\r\n]+(?:`[^`\r\n]+)*``(?!`)|`[^`\r\n]+`(?!`))/,lookbehind:!0,greedy:!0,alias:["code","keyword"]},url:{pattern:n('!?\\[(?:(?!\\])<inner>)+\\](?:\\([^\\s)]+(?:[	 ]+"(?:\\\\.|[^"\\\\])*")?\\)|[ 	]?\\[(?:(?!\\])<inner>)+\\])'),lookbehind:!0,greedy:!0,inside:{operator:/^!/,content:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0,inside:{}},variable:{pattern:/(^\][ \t]?\[)[^\]]+(?=\]$)/,lookbehind:!0},url:{pattern:/(^\]\()[^\s)]+/,lookbehind:!0},string:{pattern:/(^[ \t]+)"(?:\\.|[^"\\])*"(?=\)$)/,lookbehind:!0}}}}),["url","bold","italic","strike"].forEach((function(d){["url","bold","italic","strike","code-snippet"].forEach((function(u){d!==u&&(e.languages.markdown[d].inside.content.inside[u]=e.languages.markdown[u])}))})),e.hooks.add("after-tokenize",(function(d){d.language!=="markdown"&&d.language!=="md"||(function u(h){if(h&&typeof h!="string")for(var w=0,S=h.length;w<S;w++){var F=h[w];if(F.type==="code"){var A=F.content[1],x=F.content[3];if(A&&x&&A.type==="code-language"&&x.type==="code-block"&&typeof A.content=="string"){var v=A.content.replace(/\b#/g,"sharp").replace(/\b\+\+/g,"pp"),_="language-"+(v=(/[a-z][\w-]*/i.exec(v)||[""])[0].toLowerCase());x.alias?typeof x.alias=="string"?x.alias=[x.alias,_]:x.alias.push(_):x.alias=[_]}}else u(F.content)}})(d.tokens)})),e.hooks.add("wrap",(function(d){if(d.type==="code-block"){for(var u="",h=0,w=d.classes.length;h<w;h++){var S=d.classes[h],F=/language-(.+)/.exec(S);if(F){u=F[1];break}}var A=e.languages[u];if(A)d.content=e.highlight(d.content.replace(c,"").replace(/&(\w{1,8}|#x?[\da-f]{1,8});/gi,(function(v,_){var i;return(_=_.toLowerCase())[0]==="#"?(i=_[1]==="x"?parseInt(_.slice(2),16):Number(_.slice(1)),r(i)):o[_]||v})),A,u);else if(u&&u!=="none"&&e.plugins.autoloader){var x="md-"+new Date().valueOf()+"-"+Math.floor(1e16*Math.random());d.attributes.id=x,e.plugins.autoloader.loadLanguages(u,(function(){var v=document.getElementById(x);v&&(v.innerHTML=e.highlight(v.textContent,e.languages[u],u))}))}}}));var c=RegExp(e.languages.markup.tag.pattern.source,"gi"),o={amp:"&",lt:"<",gt:">",quot:'"'},r=String.fromCodePoint||String.fromCharCode;e.languages.md=e.languages.markdown})(Prism);(function(e){function n(t,a){return"___"+t.toUpperCase()+a+"___"}Object.defineProperties(e.languages["markup-templating"]={},{buildPlaceholders:{value:function(t,a,l,c){if(t.language===a){var o=t.tokenStack=[];t.code=t.code.replace(l,(function(r){if(typeof c=="function"&&!c(r))return r;for(var d,u=o.length;t.code.indexOf(d=n(a,u))!==-1;)++u;return o[u]=r,d})),t.grammar=e.languages.markup}}},tokenizePlaceholders:{value:function(t,a){if(t.language===a&&t.tokenStack){t.grammar=e.languages[a];var l=0,c=Object.keys(t.tokenStack);(function o(r){for(var d=0;d<r.length&&!(l>=c.length);d++){var u=r[d];if(typeof u=="string"||u.content&&typeof u.content=="string"){var h=c[l],w=t.tokenStack[h],S=typeof u=="string"?u:u.content,F=n(a,h),A=S.indexOf(F);if(A>-1){++l;var x=S.substring(0,A),v=new e.Token(a,e.tokenize(w,t.grammar),"language-"+a,w),_=S.substring(A+F.length),i=[];x&&i.push.apply(i,o([x])),i.push(v),_&&i.push.apply(i,o([_])),typeof u=="string"?r.splice.apply(r,[d,1].concat(i)):u.content=i}}else u.content&&o(u.content)}return r})(t.tokens)}}}})})(Prism);var Oe={},Le;function Sn(){return Le||(Le=1,(function(e){var n=/\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/,t=[{pattern:/\b(?:false|true)\b/i,alias:"boolean"},{pattern:/(::\s*)\b[a-z_]\w*\b(?!\s*\()/i,greedy:!0,lookbehind:!0},{pattern:/(\b(?:case|const)\s+)\b[a-z_]\w*(?=\s*[;=])/i,greedy:!0,lookbehind:!0},/\b(?:null)\b/i,/\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/],a=/\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i,l=/<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/,c=/[{}\[\](),:;]/;e.languages.php={delimiter:{pattern:/\?>$|^<\?(?:php(?=\s)|=)?/i,alias:"important"},comment:n,variable:/\$+(?:\w+\b|(?=\{))/,package:{pattern:/(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,lookbehind:!0,inside:{punctuation:/\\/}},"class-name-definition":{pattern:/(\b(?:class|enum|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,lookbehind:!0,alias:"class-name"},"function-definition":{pattern:/(\bfunction\s+)[a-z_]\w*(?=\s*\()/i,lookbehind:!0,alias:"function"},keyword:[{pattern:/(\(\s*)\b(?:array|bool|boolean|float|int|integer|object|string)\b(?=\s*\))/i,alias:"type-casting",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string)\b(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|never|object|self|static|string|void)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/\b(?:array(?!\s*\()|bool|float|int|iterable|mixed|object|string|void)\b/i,alias:"type-declaration",greedy:!0},{pattern:/(\|\s*)(?:false|null)\b|\b(?:false|null)(?=\s*\|)/i,alias:"type-declaration",greedy:!0,lookbehind:!0},{pattern:/\b(?:parent|self|static)(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(\byield\s+)from\b/i,lookbehind:!0},/\bclass\b/i,{pattern:/((?:^|[^\s>:]|(?:^|[^-])>|(?:^|[^:]):)\s*)\b(?:abstract|and|array|as|break|callable|case|catch|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|enum|eval|exit|extends|final|finally|fn|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|match|namespace|never|new|or|parent|print|private|protected|public|readonly|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield|__halt_compiler)\b/i,lookbehind:!0}],"argument-name":{pattern:/([(,]\s*)\b[a-z_]\w*(?=\s*:(?!:))/i,lookbehind:!0},"class-name":[{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/(\|\s*)\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,greedy:!0},{pattern:/(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,alias:"class-name-fully-qualified",greedy:!0,inside:{punctuation:/\\/}},{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*\$)/i,alias:"type-declaration",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-declaration"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,alias:["class-name-fully-qualified","static-context"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-hint"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:["class-name-fully-qualified","return-type"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:t,function:{pattern:/(^|[^\\\w])\\?[a-z_](?:[\w\\]*\w)?(?=\s*\()/i,lookbehind:!0,inside:{punctuation:/\\/}},property:{pattern:/(->\s*)\w+/,lookbehind:!0},number:a,operator:l,punctuation:c};var o={pattern:/\{\$(?:\{(?:\{[^{}]+\}|[^{}]+)\}|[^{}])+\}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)?)/,lookbehind:!0,inside:e.languages.php},r=[{pattern:/<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,alias:"nowdoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<'[^']+'|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<'?|[';]$/}}}},{pattern:/<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<"?|[";]$/}},interpolation:o}},{pattern:/`(?:\\[\s\S]|[^\\`])*`/,alias:"backtick-quoted-string",greedy:!0},{pattern:/'(?:\\[\s\S]|[^\\'])*'/,alias:"single-quoted-string",greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,alias:"double-quoted-string",greedy:!0,inside:{interpolation:o}}];e.languages.insertBefore("php","variable",{string:r,attribute:{pattern:/#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,greedy:!0,inside:{"attribute-content":{pattern:/^(#\[)[\s\S]+(?=\]$)/,lookbehind:!0,inside:{comment:n,string:r,"attribute-class-name":[{pattern:/([^:]|^)\b[a-z_]\w*(?!\\)\b/i,alias:"class-name",greedy:!0,lookbehind:!0},{pattern:/([^:]|^)(?:\\?\b[a-z_]\w*)+/i,alias:["class-name","class-name-fully-qualified"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:t,number:a,operator:l,punctuation:c}},delimiter:{pattern:/^#\[|\]$/,alias:"punctuation"}}}}),e.hooks.add("before-tokenize",(function(d){/<\?/.test(d.code)&&e.languages["markup-templating"].buildPlaceholders(d,"php",/<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/g)})),e.hooks.add("after-tokenize",(function(d){e.languages["markup-templating"].tokenizePlaceholders(d,"php")}))})(Prism)),Oe}Sn();var Me={},Be;function xn(){return Be||(Be=1,(function(e){var n=/\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record(?!\s*[(){}[\]<>=%~.:,;?+\-*/&|^])|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/,t="(?:[a-z]\\w*\\s*\\.\\s*)*(?:[A-Z]\\w*\\s*\\.\\s*)*",a={pattern:RegExp("(^|[^\\w.])"+t+"[A-Z](?:[\\d_A-Z]*[a-z]\\w*)?\\b"),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}},punctuation:/\./}};e.languages.java=e.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"/,lookbehind:!0,greedy:!0},"class-name":[a,{pattern:RegExp("(^|[^\\w.])"+t+"[A-Z]\\w*(?=\\s+\\w+\\s*[;,=()]|\\s*(?:\\[[\\s,]*\\]\\s*)?::\\s*new\\b)"),lookbehind:!0,inside:a.inside},{pattern:RegExp("(\\b(?:class|enum|extends|implements|instanceof|interface|new|record|throws)\\s+)"+t+"[A-Z]\\w*\\b"),lookbehind:!0,inside:a.inside}],keyword:n,function:[e.languages.clike.function,{pattern:/(::\s*)[a-z_]\w*/,lookbehind:!0}],number:/\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i,operator:{pattern:/(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m,lookbehind:!0},constant:/\b[A-Z][A-Z_\d]+\b/}),e.languages.insertBefore("java","string",{"triple-quoted-string":{pattern:/"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/,greedy:!0,alias:"string"},char:{pattern:/'(?:\\.|[^'\\\r\n]){1,6}'/,greedy:!0}}),e.languages.insertBefore("java","class-name",{annotation:{pattern:/(^|[^.])@\w+(?:\s*\.\s*\w+)*/,lookbehind:!0,alias:"punctuation"},generics:{pattern:/<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/,inside:{"class-name":a,keyword:n,punctuation:/[<>(),.:]/,operator:/[?&|]/}},import:[{pattern:RegExp("(\\bimport\\s+)"+t+"(?:[A-Z]\\w*|\\*)(?=\\s*;)"),lookbehind:!0,inside:{namespace:a.inside.namespace,punctuation:/\./,operator:/\*/,"class-name":/\w+/}},{pattern:RegExp("(\\bimport\\s+static\\s+)"+t+"(?:\\w+|\\*)(?=\\s*;)"),lookbehind:!0,alias:"static",inside:{namespace:a.inside.namespace,static:/\b\w+$/,punctuation:/\./,operator:/\*/,"class-name":/\w+/}}],namespace:{pattern:RegExp("(\\b(?:exports|import(?:\\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\\s+)(?!<keyword>)[a-z]\\w*(?:\\.[a-z]\\w*)*\\.?".replace(/<keyword>/g,(function(){return n.source}))),lookbehind:!0,inside:{punctuation:/\./}}})})(Prism)),Me}xn();var qe={},He;function $n(){return He||(He=1,Prism.languages.python={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},"string-interpolation":{pattern:/(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,lookbehind:!0,inside:{"format-spec":{pattern:/(:)[^:(){}]+(?=\}$)/,lookbehind:!0},"conversion-option":{pattern:/![sra](?=[:}]$)/,alias:"punctuation"},rest:null}},string:/[\s\S]+/}},"triple-quoted-string":{pattern:/(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,greedy:!0,alias:"string"},string:{pattern:/(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,greedy:!0},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,lookbehind:!0},"class-name":{pattern:/(\bclass\s+)\w+/i,lookbehind:!0},decorator:{pattern:/(^[\t ]*)@\w+(?:\.\w+)*/m,lookbehind:!0,alias:["annotation","punctuation"],inside:{punctuation:/\./}},keyword:/\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,builtin:/\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,boolean:/\b(?:False|None|True)\b/,number:/\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,operator:/[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},Prism.languages.python["string-interpolation"].inside.interpolation.inside.rest=Prism.languages.python,Prism.languages.py=Prism.languages.python),qe}$n();Prism.languages.swift={comment:{pattern:/(^|[^\\:])(?:\/\/.*|\/\*(?:[^/*]|\/(?!\*)|\*(?!\/)|\/\*(?:[^*]|\*(?!\/))*\*\/)*\*\/)/,lookbehind:!0,greedy:!0},"string-literal":[{pattern:RegExp(`(^|[^"#])(?:"(?:\\\\(?:\\((?:[^()]|\\([^()]*\\))*\\)|\r
|[^(])|[^\\\\\r
"])*"|"""(?:\\\\(?:\\((?:[^()]|\\([^()]*\\))*\\)|[^(])|[^\\\\"]|"(?!""))*""")(?!["#])`),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\\($/,alias:"punctuation"},punctuation:/\\(?=[\r\n])/,string:/[\s\S]+/}},{pattern:RegExp(`(^|[^"#])(#+)(?:"(?:\\\\(?:#+\\((?:[^()]|\\([^()]*\\))*\\)|\r
|[^#])|[^\\\\\r
])*?"|"""(?:\\\\(?:#+\\((?:[^()]|\\([^()]*\\))*\\)|[^#])|[^\\\\])*?""")\\2`),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\#+\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\#+\($/,alias:"punctuation"},string:/[\s\S]+/}}],directive:{pattern:RegExp("#(?:(?:elseif|if)\\b(?:[ 	]*(?:![ 	]*)?(?:\\b\\w+\\b(?:[ 	]*\\((?:[^()]|\\([^()]*\\))*\\))?|\\((?:[^()]|\\([^()]*\\))*\\))(?:[ 	]*(?:&&|\\|\\|))?)+|(?:else|endif)\\b)"),alias:"property",inside:{"directive-name":/^#\w+/,boolean:/\b(?:false|true)\b/,number:/\b\d+(?:\.\d+)*\b/,operator:/!|&&|\|\||[<>]=?/,punctuation:/[(),]/}},literal:{pattern:/#(?:colorLiteral|column|dsohandle|file(?:ID|Literal|Path)?|function|imageLiteral|line)\b/,alias:"constant"},"other-directive":{pattern:/#\w+\b/,alias:"property"},attribute:{pattern:/@\w+/,alias:"atrule"},"function-definition":{pattern:/(\bfunc\s+)\w+/,lookbehind:!0,alias:"function"},label:{pattern:/\b(break|continue)\s+\w+|\b[a-zA-Z_]\w*(?=\s*:\s*(?:for|repeat|while)\b)/,lookbehind:!0,alias:"important"},keyword:/\b(?:Any|Protocol|Self|Type|actor|as|assignment|associatedtype|associativity|async|await|break|case|catch|class|continue|convenience|default|defer|deinit|didSet|do|dynamic|else|enum|extension|fallthrough|fileprivate|final|for|func|get|guard|higherThan|if|import|in|indirect|infix|init|inout|internal|is|isolated|lazy|left|let|lowerThan|mutating|none|nonisolated|nonmutating|open|operator|optional|override|postfix|precedencegroup|prefix|private|protocol|public|repeat|required|rethrows|return|right|safe|self|set|some|static|struct|subscript|super|switch|throw|throws|try|typealias|unowned|unsafe|var|weak|where|while|willSet)\b/,boolean:/\b(?:false|true)\b/,nil:{pattern:/\bnil\b/,alias:"constant"},"short-argument":/\$\d+\b/,omit:{pattern:/\b_\b/,alias:"keyword"},number:/\b(?:[\d_]+(?:\.[\de_]+)?|0x[a-f0-9_]+(?:\.[a-f0-9p_]+)?|0b[01_]+|0o[0-7_]+)\b/i,"class-name":/\b[A-Z](?:[A-Z_\d]*[a-z]\w*)?\b/,function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:[A-Z_]{2,}|k[A-Z][A-Za-z_]+)\b/,operator:/[-+*/%=!<>&|^~?]+|\.[.\-+*/%=!<>&|^~?]+/,punctuation:/[{}[\]();,.:\\]/},Prism.languages.swift["string-literal"].forEach((function(e){e.inside.interpolation.inside=Prism.languages.swift}));(function(e){var n=[/\b(?:async|sync|yield)\*/,/\b(?:abstract|assert|async|await|break|case|catch|class|const|continue|covariant|default|deferred|do|dynamic|else|enum|export|extends|extension|external|factory|final|finally|for|get|hide|if|implements|import|in|interface|library|mixin|new|null|on|operator|part|rethrow|return|set|show|static|super|switch|sync|this|throw|try|typedef|var|void|while|with|yield)\b/],t="(^|[^\\w.])(?:[a-z]\\w*\\s*\\.\\s*)*(?:[A-Z]\\w*\\s*\\.\\s*)*",a={pattern:RegExp(t+"[A-Z](?:[\\d_A-Z]*[a-z]\\w*)?\\b"),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}}}};e.languages.dart=e.languages.extend("clike",{"class-name":[a,{pattern:RegExp(t+"[A-Z]\\w*(?=\\s+\\w+\\s*[;,=()])"),lookbehind:!0,inside:a.inside}],keyword:n,operator:/\bis!|\b(?:as|is)\b|\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?/}),e.languages.insertBefore("dart","string",{"string-literal":{pattern:/r?(?:("""|''')[\s\S]*?\1|(["'])(?:\\.|(?!\2)[^\\\r\n])*\2(?!\2))/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,lookbehind:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:e.languages.dart}}},string:/[\s\S]+/}},string:void 0}),e.languages.insertBefore("dart","class-name",{metadata:{pattern:/@\w+/,alias:"function"}}),e.languages.insertBefore("dart","class-name",{generics:{pattern:/<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<[\w\s,.&?]*>)*>)*>)*>/,inside:{"class-name":a,keyword:n,punctuation:/[<>(),.:]/,operator:/[?&|]/}}})})(Prism);Prism.languages.c=Prism.languages.extend("clike",{comment:{pattern:/\/\/(?:[^\r\n\\]|\\(?:\r\n?|\n|(?![\r\n])))*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"class-name":{pattern:/(\b(?:enum|struct)\s+(?:__attribute__\s*\(\([\s\S]*?\)\)\s*)?)\w+|\b[a-z]\w*_t\b/,lookbehind:!0},keyword:/\b(?:_Alignas|_Alignof|_Atomic|_Bool|_Complex|_Generic|_Imaginary|_Noreturn|_Static_assert|_Thread_local|__attribute__|asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|inline|int|long|register|return|short|signed|sizeof|static|struct|switch|typedef|typeof|union|unsigned|void|volatile|while)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,operator:/>>=?|<<=?|->|([-+&|:])\1|[?:~]|[-+*/%&|^!=<>]=?/}),Prism.languages.insertBefore("c","string",{char:{pattern:/'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n]){0,32}'/,greedy:!0}}),Prism.languages.insertBefore("c","string",{macro:{pattern:/(^[\t ]*)#\s*[a-z](?:[^\r\n\\/]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{string:[{pattern:/^(#\s*include\s*)<[^>]+>/,lookbehind:!0},Prism.languages.c.string],char:Prism.languages.c.char,comment:Prism.languages.c.comment,"macro-name":[{pattern:/(^#\s*define\s+)\w+\b(?!\()/i,lookbehind:!0},{pattern:/(^#\s*define\s+)\w+\b(?=\()/i,lookbehind:!0,alias:"function"}],directive:{pattern:/^(#\s*)[a-z]+/,lookbehind:!0,alias:"keyword"},"directive-hash":/^#/,punctuation:/##|\\(?=[\r\n])/,expression:{pattern:/\S[\s\S]*/,inside:Prism.languages.c}}}}),Prism.languages.insertBefore("c","function",{constant:/\b(?:EOF|NULL|SEEK_CUR|SEEK_END|SEEK_SET|__DATE__|__FILE__|__LINE__|__TIMESTAMP__|__TIME__|__func__|stderr|stdin|stdout)\b/}),delete Prism.languages.c.boolean;(function(e){var n=/[*&][^\s[\]{},]+/,t=/!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/,a="(?:"+t.source+"(?:[ 	]+"+n.source+")?|"+n.source+"(?:[ 	]+"+t.source+")?)",l="(?:[^\\s\\x00-\\x08\\x0e-\\x1f!\"#%&'*,\\-:>?@[\\]`{|}\\x7f-\\x84\\x86-\\x9f\\ud800-\\udfff\\ufffe\\uffff]|[?:-]<PLAIN>)(?:[ 	]*(?:(?![#:])<PLAIN>|:<PLAIN>))*".replace(/<PLAIN>/g,(function(){return"[^\\s\\x00-\\x08\\x0e-\\x1f,[\\]{}\\x7f-\\x84\\x86-\\x9f\\ud800-\\udfff\\ufffe\\uffff]"})),c=`"(?:[^"\\\\\r
]|\\\\.)*"|'(?:[^'\\\\\r
]|\\\\.)*'`;function o(r,d){d=(d||"").replace(/m/g,"")+"m";var u=`([:\\-,[{]\\s*(?:\\s<<prop>>[ 	]+)?)(?:<<value>>)(?=[ 	]*(?:$|,|\\]|\\}|(?:[\r
]\\s*)?#))`.replace(/<<prop>>/g,(function(){return a})).replace(/<<value>>/g,(function(){return r}));return RegExp(u,d)}e.languages.yaml={scalar:{pattern:RegExp(`([\\-:]\\s*(?:\\s<<prop>>[ 	]+)?[|>])[ 	]*(?:((?:\r?
|\r)[ 	]+)\\S[^\r
]*(?:\\2[^\r
]+)*)`.replace(/<<prop>>/g,(function(){return a}))),lookbehind:!0,alias:"string"},comment:/#.*/,key:{pattern:RegExp(`((?:^|[:\\-,[{\r
?])[ 	]*(?:<<prop>>[ 	]+)?)<<key>>(?=\\s*:\\s)`.replace(/<<prop>>/g,(function(){return a})).replace(/<<key>>/g,(function(){return"(?:"+l+"|"+c+")"}))),lookbehind:!0,greedy:!0,alias:"atrule"},directive:{pattern:/(^[ \t]*)%.+/m,lookbehind:!0,alias:"important"},datetime:{pattern:o("\\d{4}-\\d\\d?-\\d\\d?(?:[tT]|[ 	]+)\\d\\d?:\\d{2}:\\d{2}(?:\\.\\d*)?(?:[ 	]*(?:Z|[-+]\\d\\d?(?::\\d{2})?))?|\\d{4}-\\d{2}-\\d{2}|\\d\\d?:\\d{2}(?::\\d{2}(?:\\.\\d*)?)?"),lookbehind:!0,alias:"number"},boolean:{pattern:o("false|true","i"),lookbehind:!0,alias:"important"},null:{pattern:o("null|~","i"),lookbehind:!0,alias:"important"},string:{pattern:o(c),lookbehind:!0,greedy:!0},number:{pattern:o("[+-]?(?:0x[\\da-f]+|0o[0-7]+|(?:\\d+(?:\\.\\d*)?|\\.\\d+)(?:e[+-]?\\d+)?|\\.inf|\\.nan)","i"),lookbehind:!0},tag:t,important:n,punctuation:/---|[:[\]{}\-,|>?]|\.\.\./},e.languages.yml=e.languages.yaml})(Prism);(function(e){function n(c,o){e.languages[c]&&e.languages.insertBefore(c,"comment",{"doc-comment":o})}var t=e.languages.markup.tag,a={pattern:/\/\/\/.*/,greedy:!0,alias:"comment",inside:{tag:t}},l={pattern:/'''.*/,greedy:!0,alias:"comment",inside:{tag:t}};n("csharp",a),n("fsharp",a),n("vbnet",l)})(Prism);const An=["innerHTML"],En=H({__name:"DfMdRender",props:{content:{type:String,default:""}},setup(e){const{$md:n}=ft();return ht(()=>{Ne.highlightAll()}),mt(()=>{Ne.highlightAll()}),(t,a)=>(y(),T("div",{class:"html-md-render",innerHTML:bt(n).render(e.content)},null,8,An))}}),_e=U(En,[["__scopeId","data-v-6875820b"]]),Fn="mdi-checkbox-marked-circle",Ue="mdi-content-copy",Tn=H({name:"DfCopyClipboard",props:{text:{type:String,default:null},color:{type:String,default:null},end:{type:Boolean,default:!1},start:{type:Boolean,default:!1},size:{type:String,default:"small"}},data(){return{icon:Ue,localColor:null}},watch:{color:{immediate:!0,handler(e){this.localColor=e}}},methods:{copyText(){this.icon=Fn,this.localColor="success",navigator.clipboard.writeText(this.text),setTimeout(this.reset,1e3)},reset(){this.icon=Ue,this.localColor=this.color}}});function In(e,n,t,a,l,c){return y(),E(ee,{size:e.size,onClick:e.copyText},{default:D(()=>[$(ie,{size:e.size,end:e.end,start:e.start,color:e.localColor},{default:D(()=>[se(B(e.icon),1)]),_:1},8,["size","end","start","color"])]),_:1},8,["size","onClick"])}const Dn=U(Tn,[["render",In]]),Pn=H({name:"DfMarkdownCode",components:{DfMdRender:_e,DfCopyClipboard:Dn},props:{content:{type:String,required:!0}},data(){return{localContent:"",maxNumberOfContentLines:20,contentExpanded:!1}},computed:{formattedContent(){return this.content?.replace(/^```[^\n]*\n?|```\s*$/g,"")},showExpandContentButtons(){return this.formattedContent?.split(`
`)?.length>this.maxNumberOfContentLines}},watch:{content:{immediate:!0,handler(e){this.localContent=e,this.collapseContent()}}},methods:{expandContent(){this.localContent=this.content,this.contentExpanded=!0},collapseContent(){this.showExpandContentButtons===!0&&(this.localContent=this.localContent?.split(`
`)?.slice(0,this.maxNumberOfContentLines).join(`
`)+"\n...\n```",this.contentExpanded=!1)}}}),Cn={style:{position:"relative"}},Rn={style:{position:"absolute",top:"0",right:"0"},class:"d-flex align-center mt-3 mr-3"},zn={key:0,class:"mr-2"};function Vn(e,n,t,a,l,c){const o=V("DfMdRender"),r=V("DfCopyClipboard");return y(),T("div",Cn,[$(o,{format:"MARKDOWN",content:e.localContent},null,8,["content"]),R("div",Rn,[e.showExpandContentButtons?(y(),T("div",zn,[e.contentExpanded===!1?(y(),E(ee,{key:0,size:"x-small",style:{"margin-top":"-2px"},onClick:e.expandContent},{default:D(()=>[$(ie,{size:"x-small",color:"black"},{default:D(()=>[...n[0]||(n[0]=[se(" mdi-arrow-expand ",-1)])]),_:1})]),_:1},8,["onClick"])):(y(),E(ee,{key:1,size:"x-small",style:{"margin-top":"-2px"},onClick:e.collapseContent},{default:D(()=>[$(ie,{size:"x-small",color:"black"},{default:D(()=>[...n[1]||(n[1]=[se(" mdi-arrow-collapse ",-1)])]),_:1})]),_:1},8,["onClick"]))])):z("",!0),$(r,{text:e.formattedContent,size:"x-small"},null,8,["text"])])])}const at=U(Pn,[["render",Vn]]),Nn=H({name:"DfMarkdownTabs",components:{DfMdRender:_e,DfMarkdownCode:at},props:{tabsData:{type:Object,default:null},tabsDataIndex:{type:Number,default:0},format:{type:String,default:Ke.Markdown}},data(){return{tabs:[]}}}),Se=Symbol.for("vuetify:v-tabs"),On=ue({fixed:Boolean,sliderColor:String,hideSlider:Boolean,direction:{type:String,default:"horizontal"},...Ze(wt({selectedClass:"v-tab--selected",variant:"text"}),["active","block","flat","location","position","symbol"])},"VTab"),rt=le()({name:"VTab",props:On(),setup(e,n){let{slots:t,attrs:a}=n;const{textColorClasses:l,textColorStyles:c}=yt(e,"sliderColor"),o=Ee(),r=Ee(),d=oe(()=>e.direction==="horizontal"),u=oe(()=>o.value?.group?.isSelected.value??!1);function h(w){let{value:S}=w;if(S){const F=o.value?.$el.parentElement?.querySelector(".v-tab--selected .v-tab__slider"),A=r.value;if(!F||!A)return;const x=getComputedStyle(F).color,v=F.getBoundingClientRect(),_=A.getBoundingClientRect(),i=d.value?"x":"y",s=d.value?"X":"Y",g=d.value?"right":"bottom",p=d.value?"width":"height",f=v[i],b=_[i],k=f>b?v[g]-_[g]:v[i]-_[i],m=Math.sign(k)>0?d.value?"right":"bottom":Math.sign(k)<0?d.value?"left":"top":"center",P=(Math.abs(k)+(Math.sign(k)<0?v[p]:_[p]))/Math.max(v[p],_[p])||0,L=v[p]/_[p]||0,Y=1.5;kt(A,{backgroundColor:[x,"currentcolor"],transform:[`translate${s}(${k}px) scale${s}(${L})`,`translate${s}(${k/Y}px) scale${s}(${(P-1)/Y+1})`,"none"],transformOrigin:Array(3).fill(m)},{duration:225,easing:_t})}}return ce(()=>{const w=ee.filterProps(e);return $(ee,Z({symbol:Se,ref:o,class:["v-tab",e.class],style:e.style,tabindex:u.value?0:-1,role:"tab","aria-selected":String(u.value),active:!1},w,a,{block:e.fixed,maxWidth:e.fixed?300:void 0,"onGroup:selected":h}),{...t,default:()=>$(O,null,[t.default?.()??e.text,!e.hideSlider&&$("div",{ref:r,class:["v-tab__slider",l.value],style:c.value},null)])})}),vt({},o)}}),Ln=ue({...Ze(xt(),["continuous","nextIcon","prevIcon","showArrows","touch","mandatory"])},"VTabsWindow"),it=le()({name:"VTabsWindow",props:Ln(),emits:{"update:modelValue":e=>!0},setup(e,n){let{slots:t}=n;const a=St(Se,null),l=Xe(e,"modelValue"),c=oe({get(){return l.value!=null||!a?l.value:a.items.value.find(o=>a.selected.value.includes(o.id))?.value},set(o){l.value=o}});return ce(()=>{const o=Fe.filterProps(e);return $(Fe,Z({_as:"VTabsWindow"},o,{modelValue:c.value,"onUpdate:modelValue":r=>c.value=r,class:["v-tabs-window",e.class],style:e.style,mandatory:!1,touch:!1}),t)}),{}}}),Mn=ue({...$t()},"VTabsWindowItem"),st=le()({name:"VTabsWindowItem",props:Mn(),setup(e,n){let{slots:t}=n;return ce(()=>{const a=Te.filterProps(e);return $(Te,Z({_as:"VTabsWindowItem"},a,{class:["v-tabs-window-item",e.class],style:e.style}),t)}),{}}});function Bn(e){return e?e.map(n=>Rt(n)?n:{text:n,value:n}):[]}const qn=ue({alignTabs:{type:String,default:"start"},color:String,fixedTabs:Boolean,items:{type:Array,default:()=>[]},stacked:Boolean,bgColor:String,grow:Boolean,height:{type:[Number,String],default:void 0},hideSlider:Boolean,sliderColor:String,...Ct({mandatory:"force",selectedClass:"v-tab-item--selected"}),...Pt(),...Dt()},"VTabs"),Hn=le()({name:"VTabs",props:qn(),emits:{"update:modelValue":e=>!0},setup(e,n){let{attrs:t,slots:a}=n;const l=Xe(e,"modelValue"),c=oe(()=>Bn(e.items)),{densityClasses:o}=At(e),{backgroundColorClasses:r,backgroundColorStyles:d}=Et(G(e,"bgColor")),{scopeId:u}=Ft();return Tt({VTab:{color:G(e,"color"),direction:G(e,"direction"),stacked:G(e,"stacked"),fixed:G(e,"fixedTabs"),sliderColor:G(e,"sliderColor"),hideSlider:G(e,"hideSlider")}}),ce(()=>{const h=Ie.filterProps(e),w=!!(a.window||e.items.length>0);return $(O,null,[$(Ie,Z(h,{modelValue:l.value,"onUpdate:modelValue":S=>l.value=S,class:["v-tabs",`v-tabs--${e.direction}`,`v-tabs--align-tabs-${e.alignTabs}`,{"v-tabs--fixed-tabs":e.fixedTabs,"v-tabs--grow":e.grow,"v-tabs--stacked":e.stacked},o.value,r.value,e.class],style:[{"--v-tabs-height":It(e.height)},d.value,e.style],role:"tablist",symbol:Se},u,t),{default:()=>[a.default?.()??c.value.map(S=>a.tab?.({item:S})??$(rt,Z(S,{key:S.text,value:S.value}),{default:a[`tab.${S.value}`]?()=>a[`tab.${S.value}`]?.({item:S}):void 0}))]}),w&&$(it,Z({modelValue:l.value,"onUpdate:modelValue":S=>l.value=S,key:"tabs-window"},u),{default:()=>[c.value.map(S=>a.item?.({item:S})??$(st,{value:S.value},{default:()=>a[`item.${S.value}`]?.({item:S})})),a.window?.()]})])}),{}}}),Un={class:"d-flex align-center"},jn={class:"mb-0"};function Gn(e,n,t,a,l,c){const o=V("DfMdRender"),r=V("DfMarkdownCode");return e.tabsData!==null?(y(),E(ke,{key:0,variant:"outlined",flat:"",class:"markdown-tabs"},{default:D(()=>[$(Hn,{modelValue:e.tabs[e.tabsDataIndex],"onUpdate:modelValue":n[0]||(n[0]=d=>e.tabs[e.tabsDataIndex]=d)},{default:D(()=>[(y(!0),T(O,null,X(e.tabsData.tabsHeaders,d=>(y(),E(rt,{key:d,style:{"text-transform":"none"},value:e.tabs[e.tabsDataIndex]},{default:D(()=>[R("div",Un,[$(Ge,{eager:"",src:`/technologies/blackandwhite/${d.split(" ").join("_").toLowerCase()}.png`,width:"15",class:"mr-2"},null,8,["src"]),R("p",jn,B(d),1)])]),_:2},1032,["value"]))),128))]),_:1},8,["modelValue"]),$(it,{modelValue:e.tabs[e.tabsDataIndex],"onUpdate:modelValue":n[1]||(n[1]=d=>e.tabs[e.tabsDataIndex]=d)},{default:D(()=>[(y(!0),T(O,null,X(e.tabsData.tabsContent,d=>(y(),E(st,{key:`tabItem-${d.length}`,transition:!1,"reverse-transition":!1,value:e.tabs[e.tabsDataIndex]},{default:D(()=>[(y(!0),T(O,null,X(d,u=>(y(),T("div",{key:`tabContent-${u.type}`},[u.type==="text"?(y(),E(o,{key:0,format:e.format,content:u.content},null,8,["format","content"])):u.type==="code"?(y(),E(r,{key:1,content:u.content},null,8,["content"])):z("",!0)]))),128))]),_:2},1032,["value"]))),128))]),_:1},8,["modelValue"])]),_:1})):z("",!0)}const Wn=U(Nn,[["render",Gn]]);var Q=(e=>(e.StartTabs="===",e.StartCode="```",e))(Q||{});const je={"===":/^(?!\t)(?!===)\S+(?:\s+\S*)*$/,"```":/^```\s*$/},ye=[/^\t/,/^```/];class W{static enhanceMarkdown(n){const t=[],a={[Q.StartTabs]:W.formatToTabs,[Q.StartCode]:W.formatToCode},l=Object.keys(je),c=n?.split(`
`);let o="text",r="",d=null;return(c||[]).forEach((u,h)=>{const w=o!=="custom"&&l.some(F=>u.startsWith(F)===!0),S=o==="custom"&&je[d||""].test(u)===!0;if(w===!0)o==="text"&&r.trim()!==""&&(t.push({type:"text",content:r}),r=""),d=l.find(F=>u.includes(F)),o="custom",r+=u+`
`;else if(S===!0||o==="custom"&&h===c.length-1){h===c.length-1&&ye.some(A=>A.test(u)===!0)===!0?r+=u+`
`:h!==c.length-1&&ye.some(A=>A.test(u)===!0)===!0&&(r+=u);const F=a[d||""](r);t.push({type:F.type,...F.content}),o="text",r="",d=null,ye.some(A=>A.test(u))===!1&&(r+=u+`
`)}else r+=u+`
`;h===c.length-1&&o==="text"&&r.trim()!==""&&t.push({type:"text",content:r})}),t}static formatToTabs(n){const t=n?.split(`
`);let a=null;const l=[],c=[];let o="";return(t||[]).forEach(r=>{r.startsWith(Q.StartTabs)===!0?(a!=null&&o.trim()!==""&&(l.push(a),c.push(W.enhanceMarkdown(o))),a=W.formatTabId(r?.split(Q.StartTabs)[1]),o=""):o+=r.replace(/^\t/,"")+`
`}),a!=null&&o.trim()!==""&&(l.push(a),c.push(W.enhanceMarkdown(o))),{type:"tabs",content:{tabsHeaders:l,tabsContent:c}}}static formatToCode(n){return{type:"code",content:{content:n}}}static formatTabId(n){return n?.trim()?.replace(/^['"](.*)['"]$/,"$1")}}const Zn=H({name:"DfEnhancedMsRender",components:{DfMarkdownTabs:Wn,DfMarkdownCode:at,DfMdRender:_e},props:{content:{type:String,default:""},format:{type:String,default:Ke.Markdown},isEditable:{type:Boolean,default:!1}},emits:["validateDescription","update:editDescription","update:description","resetDescriptionChanges"],data(){return{editDescription:!1,enhancedMarkdown:[],editableDescription:this.content}},watch:{content:{immediate:!0,handler(e){this.enhanceMarkdown(e),this.content==="No Description"?this.editableDescription="":this.editableDescription=this.content,this.editableDescription=this.content}},editableDescription(e){this.$emit("update:description",e)},editDescription(e){this.$emit("update:editDescription",e)}},methods:{enhanceMarkdown(e){this.enhancedMarkdown=W.enhanceMarkdown(e)},switchDescriptionToReadOnly(){this.editDescription=!1},resetDescriptionChanges(){this.$emit("resetDescriptionChanges")}}}),Xn={class:"html-md-render",style:{color:"black"}},Kn={key:0},Yn={key:1,class:"hand-pointer"};function Jn(e,n,t,a,l,c){const o=V("DfMdRender"),r=V("DfMarkdownTabs"),d=V("DfMarkdownCode");return y(),T("div",Xn,[e.isEditable===!1?(y(),T("div",Kn,[(y(!0),T(O,null,X(e.enhancedMarkdown,(u,h)=>(y(),T("div",{key:h},[u.type==="text"?(y(),E(o,{key:0,format:e.format,content:u.content},null,8,["format","content"])):u.type==="tabs"?(y(),E(r,{key:1,"tabs-data":u,"tabs-data-index":h,class:"my-3"},null,8,["tabs-data","tabs-data-index"])):u.type==="code"?(y(),E(d,{key:2,content:u.content},null,8,["content"])):z("",!0)]))),128))])):(y(),T("div",Yn,[De(R("div",{onDblclick:n[0]||(n[0]=u=>e.editDescription=!0)},[(y(!0),T(O,null,X(e.enhancedMarkdown,(u,h)=>(y(),T("div",{key:h},[u.type==="text"?(y(),E(o,{key:0,format:e.format,content:u.content},null,8,["format","content"])):u.type==="tabs"?(y(),E(r,{key:1,format:e.format,"tabs-data":u,"tabs-data-index":h,class:"my-3"},null,8,["format","tabs-data","tabs-data-index"])):u.type==="code"?(y(),E(d,{key:2,content:u.content},null,8,["content"])):z("",!0)]))),128))],544),[[Pe,e.editDescription===!1]]),De($(Ht,{modelValue:e.editableDescription,"onUpdate:modelValue":n[1]||(n[1]=u=>e.editableDescription=u),"auto-grow":"","full-width":"",variant:"outlined",density:"compact",rows:"15",color:"accent",name:"Description",label:"Description",counter:"",autofocus:"",onKeydown:Ce(e.resetDescriptionChanges,["esc"]),onKeyup:n[2]||(n[2]=Ce(zt(u=>e.$emit("validateDescription"),["alt"]),["enter"]))},null,8,["modelValue","onKeydown"]),[[Pe,e.editDescription===!0]])]))])}const Qn=U(Zn,[["render",Jn]]),ve=1,ea={info:1,important:2,secure:3,hardening:4,potentially:5,low:6,medium:7,high:8,critical:9},ta=H({name:"VulnerabilityDetail",components:{VulnerabilityTitle:cn,DfMaterialCard:wn,DfEnhancedMdRender:Qn,DfBreadcrumbs:Mt},props:{scanId:{type:[Number,String],required:!0},vulnTitle:{type:String,required:!0},scanner:{type:Object,required:!0},showBreadcrumbs:{type:Boolean,default:!0}},emits:["update:loading"],data(){return{scansService:new Ut(this.$axios),currentHeight:0,loading:!0,vulnerabilityService:new he(this.$axios),mutex:new an,getVulnInfo:!0,references:{},vulnz:[],itemsPerPage:10,currentPage:1,countVulnerabilities:0,highestRiskRating:null,title:null,description:null,recommendation:null,breadcrumbs:[{text:"Scans",disabled:!1,to:"/scan/list",exact:!0},{text:"Scan",disabled:!1,exact:!0,scans:[]},{text:"Vulnerability",scanId:this.scanId,exact:!0,kbvulnerabilities:[]}]}},computed:{vulnerabilitiesCountText(){return this.countVulnerabilities===0||this.countVulnerabilities>1?`${this.countVulnerabilities} issues`:`${this.countVulnerabilities} issue`}},watch:{async vulnTitle(){this.currentPage=1,this.getVulnInfo=!0,this.vulnz=[],this.references={},await this.fetchData()},loading(e){this.$emit("update:loading",e)}},async mounted(){addEventListener("scroll",this.handleScroll),await this.fetchData()},beforeUnmount(){removeEventListener("scroll",this.handleScroll)},methods:{...Vt(Bt,["reportError"]),async fetchData(){this.vulnerabilityService=new he(this.$axios),await this.getDataFromApi(),await Promise.allSettled([this.getDataFromApi(),this.fetchKBVulnerabilities(),this.fetchScans()])},async getDataFromApi(){const e=await this.mutex.acquire();try{if(this.vulnerabilityService.hasNext===!0){if(this.loading=!0,this.getVulnInfo===!0){const n=await this.vulnerabilityService.getVulnerabilitiesWithInfo({scanner:this.scanner,scanId:parseInt(this.scanId),vulnDetailTitles:[this.vulnTitle],kbDetailTitle:this.vulnTitle,page:this.currentPage,numberElements:this.itemsPerPage}),t=(n||[])[0]?.vulnerabilities||{pageInfo:{},vulnerabilities:[]};if(this.countVulnerabilities=t?.pageInfo?.count||0,(t?.vulnerabilities||[]).length>0){const a=t?.vulnerabilities[0];this.highestRiskRating=(n||[])[0]?.highestRiskRating,this.title=a?.detail?.title,this.description=a?.detail?.description,this.recommendation=a?.detail?.recommendation;for(const l of a?.detail?.references||[])l?.title!==void 0&&l?.title!==null&&(this.references[l?.title]=l?.url)}for(const a of t?.vulnerabilities||[])this.vulnz.push({id:a?.id,content:a?.technicalDetail});this.getVulnInfo=!1}else{const n=await this.vulnerabilityService.getVulnerabilitiesWithoutInfo({scanner:this.scanner,scanId:parseInt(this.scanId),detailTitles:[this.vulnTitle],page:this.currentPage,numberElements:this.itemsPerPage});for(const t of n)this.vulnz.push({id:t?.id,content:t?.technicalDetail})}this.currentPage=this.currentPage+1}}finally{this.loading=!1,e()}},async fetchKBVulnerabilities(){try{let e=[];const n=await this.vulnerabilityService.getKBVulnerabilities(this.scanner,parseInt(this.scanId));for(const t of n?.kbVulnerabilities||[])e.push({key:t?.kb?.title,goToVulnId:!1,risk:t?.highestRiskRating,title:t?.kb?.title,description:t?.kb?.shortDescription,kb:t?.kb});e=Yt(e).by([{desc:t=>ea[t?.risk?.toLocaleLowerCase()]}]),this.breadcrumbs[2].kbvulnerabilities=e}catch(e){this.reportError(e?.message||"Error fetching scan.")}},async handleScroll(){document.documentElement.scrollTop+window.innerHeight>document.documentElement.offsetHeight-300&&this.currentHeight!==document.documentElement.offsetHeight&&this.vulnerabilityService.hasNext===!0&&await this.getDataFromApi()},async reloadData(){return this.vulnerabilityService=new he(this.$axios),this.currentPage=1,this.vulnz=[],this.getVulnInfo=!0,await this.getDataFromApi(),{vulnz:this.vulnz,riskRating:this.highestRiskRating}},async fetchScans(){this.breadcrumbs[1].scans=await this.scansService.getScans(this.scanner,{page:1,numberElements:20}),await this.updateBreadcrumbs()},async updateBreadcrumbs(){try{if((this.breadcrumbs[ve]?.scans||[]).find(n=>n.id===this.scanId)===void 0){const n=await this.scansService.getScan(this.scanner,this.scanId);this.breadcrumbs[ve].scans=[...this.breadcrumbs[ve]?.scans||[],n]}}catch{}}}}),na=["href"],aa={class:"pa-0 ma-0 mr-1 grey--text"},ra={class:"font-weight-bold d-flex align-center"},ia={class:"mb-0"};function sa(e,n,t,a,l,c){const o=V("DfBreadcrumbs"),r=V("VulnerabilityTitle"),d=V("DfEnhancedMdRender"),u=V("DfMaterialCard");return y(),T("div",null,[e.showBreadcrumbs?(y(),E(o,{key:0,"scan-id":e.scanId,"vuln-title":e.vulnTitle,breadcrumbs:e.breadcrumbs,scanner:e.scanner,class:"mb-5"},null,8,["scan-id","vuln-title","breadcrumbs","scanner"])):z("",!0),$(r,{title:e.title,"risk-rating":e.highestRiskRating,loading:e.loading},null,8,["title","risk-rating","loading"]),$(u,{color:"grey darken-1",light:"","max-width":"100%",class:"my-12",icon:"mdi-bug-outline",title:"Description"},{default:D(()=>[$(d,{content:e.description},null,8,["content"])]),_:1}),$(u,{color:"green lighten-1",light:"","max-width":"100%",class:"my-12",icon:"mdi-wrench-outline",title:"Recommendation"},{default:D(()=>[$(d,{content:e.recommendation},null,8,["content"])]),_:1}),e.references!==null?(y(),E(u,{key:1,color:"blue lighten-1",light:"","max-width":"100%",class:"my-12",icon:"mdi-link",title:"References"},{default:D(()=>[R("ul",null,[(y(!0),T(O,null,X(e.references,(h,w)=>(y(),T("li",{key:w},[R("a",{href:h,target:"_blank"},B(w),9,na)]))),128))])]),_:1})):z("",!0),$(u,{color:"red lighten-1",light:"","max-width":"100%",class:"my-12",icon:"mdi-code-braces",title:"Technical Details"},{"title-extra-info":D(()=>[R("p",aa," Has "+B(e.vulnerabilitiesCountText),1)]),default:D(()=>[(y(!0),T(O,null,X(e.vulnz,(h,w)=>(y(),T(O,{key:`issue-${h.id}-${w}`},[R("div",ra,[R("p",ia," Issue #"+B(w+1),1)]),$(d,{content:h.content},null,8,["content"]),w!==e.vulnz.length-1?(y(),E(We,{key:w,class:"mt-7 mb-4"})):z("",!0)],64))),128))]),_:1})])}const ha=U(ta,[["render",sa]]);export{ha as V,he as a,Yt as s};
